@@ -7,6 +7,6 @@ validator_application = validator(noop_application)
 
 class EnvironTest(AsyncTestCase):
 
-    def testValidWsgi(self):
+    def testValidWsgi(self) -> None:
         with self.run_server(validator_application) as client:
             client.assert_response()
